
from main import *


__package_name__        = u'blnuhr'
__description__         = u"Python & Qt rendition of Berlin's quantity didactics clock"
__long_description__    = __description__

__author__              = u'Pete R. Jemian'
__email__               = u'prjemian@gmail.com'
__institution__         = u"Late-Nite(tm) Software"
__author_name__         = __author__
__author_email__        = __email__

__copyright__           = u'2016, Pete R. Jemian'
# __license_url__         = u''
__license__             = u'OPEN SOURCE LICENSE'
__url__                 = u'https://github.com/prjemian/blnuhr/'
__download_url__        = __url__
__keywords__            = ['Python', 'Qt4', 'clock']
__requires__            = [#'PyQt4>=4',      # this project developed with PyQt4 >= 4.11.3
                          ]

__classifiers__ = [
            'Development Status :: 4 - Beta',
            'Environment :: Console',
            'Environment :: Web Environment',
            'Intended Audience :: Science/Research',
            'License :: Free To Use But Restricted',
            'Operating System :: OS Independent',
            'Programming Language :: Python',
            'Topic :: Software Development :: Libraries :: Python Modules',
            'Topic :: Utilities',
                     ]

# as shown in the About box ...
__credits__ = u'author: ' + __author__
__credits__ += u'\nemail: ' + __email__
__credits__ += u'\ninstitution: ' + __institution__
__credits__ += u'\nURL: ' + __url__

from ._version import get_versions
__version__ = get_versions()['version']
del get_versions




# Copyright (c) 2009 - 2016, Pete Jemian.
# See LICENSE file for details.

'''
(internal) support for items in resources folder, such as forms defined in .ui files
'''


import inspect
import os
#from PyQt4 import QtCore, QtGui, uic
from PyQt4 import uic


FORMS_SUBDIRECTORY = 'resources'


def loadUi(ui_file, baseinstance=None, **kw):
    '''
    load a .ui file for use in building a GUI
    
    Wraps `uic.loadUi()` with code that finds our program's
    *resources* directory.
    
    :see: http://nullege.com/codes/search/PyQt4.uic.loadUi
    :see: http://bitesofcode.blogspot.ca/2011/10/comparison-of-loading-techniques.html
    
    inspired by:
    http://stackoverflow.com/questions/14892713/how-do-you-load-ui-files-onto-python-classes-with-pyside?lq=1
    
    .. rubric:: Basic Procedure

    #. Use Qt Designer to create a .ui file.
    #. Create a python class of the same type as the widget you created in the .ui file.
    #. When initializing the python class, use uic to dynamically load the .ui file onto the class.

    Here is an example from this code:

    .. code-block:: python
        :linenos:

        from PyQt4 import QtGui
        import resources
        
        UI_FILE = 'plainTextEdit.ui'
        
        class TextWindow(QtGui.QDialog, form_class):
        
            def __init__(self, title, text):
                QtGui.QDialog.__init__(self, parent)
                resources.loadUi(UI_FILE, baseinstance=self)
                self.setWindowTitle(title)
                self.plainTextEdit.setPlainText(text)

        import sys
        app = QtGui.QApplication(sys.argv)
        win = TextWindow('the title', __doc__)
        win.show()
        sys.exit(app.exec_())

    '''
    return uic.loadUi(resource_file(ui_file), baseinstance=baseinstance, **kw)


def get_forms_path():
    '''identify our resources directory'''
    # assume this is less risky than __file__
    ref = inspect.getsourcefile(get_forms_path)
    path = os.path.abspath(os.path.dirname(ref))
    return os.path.join(path, FORMS_SUBDIRECTORY)


def resource_file(filename):
    '''absolute path to file in resources directory'''
    # assume this is less risky than __file__
    path = get_forms_path()
    return os.path.abspath(os.path.join(path, filename))



# Copyright (c) 2009 - 2016, Pete Jemian.
# See LICENSE file for details.

import datetime
import os
import sys
from PyQt4 import QtCore, QtGui
import resources


CLOCK_UI_FILE = 'blnuhr.ui'
ORANGE = {0:'''background-color: rgb(130, 85, 64);
               color: rgb(130, 85, 64);''',
          1:'''background-color: rgb(255, 170, 127);
               color: rgb(255, 170, 127);''',
         }
RED = {0:'background-color: rgb(128, 42, 64);',
       1:'background-color: rgb(255, 85, 127);',
      }
REFRESH_TIME__MS = 100


class Clock_blnuhr(QtGui.QWidget):
    '''create a widget for the clock and start it running'''

    def __init__(self, parent=None):
        QtGui.QWidget.__init__(self)
        resources.loadUi(CLOCK_UI_FILE, self)
        self.last_t = None
        self.update(None)
    
    def start(self):
        '''begin the periodic update of the clock'''
        self.timer = QtCore.QTimer(self)
        QtCore.QObject.connect(self.timer, 
                               QtCore.SIGNAL('timeout()'), 
                               self.update)
        self.timer.start(REFRESH_TIME__MS)
    
    def update(self, t=None):
        '''
        manage a periodic update of the clock
        
        Show the time as a string on the seconds LED as a tool tip
        '''
        def set_LIGHT(w, color, choice):
            w.setStyleSheet(str(color[choice]))

        t = t or datetime.datetime.now()
        
        # seconds blinker
        set_LIGHT(self.l_s, ORANGE, t.second % 2)
        self.l_s.setToolTip(str(t))

        # 5-hour markers
        if self.last_t is None or self.last_t.hour != t.hour: 
            set_LIGHT(self.l_h5_1, RED, t.hour > 4)
            set_LIGHT(self.l_h5_2, RED, t.hour > 9)
            set_LIGHT(self.l_h5_3, RED, t.hour > 14)
            set_LIGHT(self.l_h5_4, RED, t.hour > 19)

            # 1-hour markers
            h = t.hour % 5
            set_LIGHT(self.l_h1_1, RED, h > 0)
            set_LIGHT(self.l_h1_2, RED, h > 1)
            set_LIGHT(self.l_h1_3, RED, h > 2)
            set_LIGHT(self.l_h1_4, RED, h > 3)
        
        # 5-minute markers
        if self.last_t is None or self.last_t.minute != t.minute: 
            set_LIGHT(self.l_m5_1,  ORANGE, t.minute > 4)
            set_LIGHT(self.l_m5_2,  ORANGE, t.minute > 9)
            set_LIGHT(self.l_m5_3,  RED,    t.minute > 14)
            set_LIGHT(self.l_m5_4,  ORANGE, t.minute > 19)
            set_LIGHT(self.l_m5_5,  ORANGE, t.minute > 24)
            set_LIGHT(self.l_m5_6,  RED,    t.minute > 29)
            set_LIGHT(self.l_m5_7,  ORANGE, t.minute > 34)
            set_LIGHT(self.l_m5_8,  ORANGE, t.minute > 39)
            set_LIGHT(self.l_m5_9,  RED,    t.minute > 44)
            set_LIGHT(self.l_m5_10, ORANGE, t.minute > 49)
            set_LIGHT(self.l_m5_11, ORANGE, t.minute > 54)
    
            # 1-minute markers
            m = t.minute % 5
            set_LIGHT(self.l_m1_1, ORANGE, m > 0)
            set_LIGHT(self.l_m1_2, ORANGE, m > 1)
            set_LIGHT(self.l_m1_3, ORANGE, m > 2)
            set_LIGHT(self.l_m1_4, ORANGE, m > 3)
        
        # for next time
        self.last_t = t


def main ():
    '''entry point to run standalone'''
    app = QtGui.QApplication(sys.argv)
    clock = Clock_blnuhr()
    clock.show()
    clock.start()
    sys.exit(app.exec_())


if __name__ == '__main__':
    main()



#!/usr/bin/env python

# Copyright (c) 2009 - 2015, UChicago Argonne, LLC.
# See LICENSE file for details.


from setuptools import setup, find_packages
import os
import re
import sys
import versioneer

# pull in some definitions from the package's __init__.py file
sys.path.insert(0, os.path.join('src', ))
import blnuhr

long_description = open('README.rst', 'r').read()


setup (
    name             = blnuhr.__package_name__,        # blnuhr
    license          = blnuhr.__license__,
    version          = versioneer.get_version(),
    cmdclass         = versioneer.get_cmdclass(),
    description      = blnuhr.__description__,
    long_description = long_description,
    author           = blnuhr.__author_name__,
    author_email     = blnuhr.__author_email__,
    url              = blnuhr.__url__,
    download_url     = blnuhr.__download_url__,
    keywords         = blnuhr.__keywords__,
    install_requires = blnuhr.__requires__,
    platforms        = 'any',
    package_dir      = {'': 'src'},
    #packages         = find_packages(),
    packages         = [str(blnuhr.__package_name__), ],
    package_data     = dict(blnuhr=['resources/*', 'LICENSE', ]),
    classifiers      = blnuhr.__classifiers__,
    entry_points={
       # create & install console_scripts in <python>/bin
       #'console_scripts': ['blnuhr = blnuhr.main:main'],
       'gui_scripts': ['blnuhr = blnuhr:main'],
       },
      )
